@@ -156,6 +156,7 @@ from bitmovin_api_sdk.models.broadcast_ts_muxing import BroadcastTsMuxing
 from bitmovin_api_sdk.models.broadcast_ts_muxing_configuration import BroadcastTsMuxingConfiguration
 from bitmovin_api_sdk.models.broadcast_ts_muxing_information import BroadcastTsMuxingInformation
 from bitmovin_api_sdk.models.broadcast_ts_program_configuration import BroadcastTsProgramConfiguration
+from bitmovin_api_sdk.models.broadcast_ts_subtitle_input_stream_configuration import BroadcastTsSubtitleInputStreamConfiguration
 from bitmovin_api_sdk.models.broadcast_ts_transport_configuration import BroadcastTsTransportConfiguration
 from bitmovin_api_sdk.models.broadcast_ts_video_input_stream_configuration import BroadcastTsVideoInputStreamConfiguration
 from bitmovin_api_sdk.models.burn_in_subtitle_dvb_sub import BurnInSubtitleDvbSub
@@ -382,6 +383,7 @@ from bitmovin_api_sdk.models.live_media_ingest_output import LiveMediaIngestOutp
 from bitmovin_api_sdk.models.local_input import LocalInput
 from bitmovin_api_sdk.models.local_output import LocalOutput
 from bitmovin_api_sdk.models.manifest import Manifest
+from bitmovin_api_sdk.models.manifest_generator import ManifestGenerator
 from bitmovin_api_sdk.models.manifest_resource import ManifestResource
 from bitmovin_api_sdk.models.manifest_type import ManifestType
 from bitmovin_api_sdk.models.manifest_type_response import ManifestTypeResponse
